pub fn _self() -> Result<PathBuf, Error>
return an PathBuf which /proc/self point to.
the returnd value should be same as ls -l /proc/self
ls -l /proc/self
there is not self() function in this crate, because self is a key word in rust.